/*
  Copyright 2019 Kakao Corp.

  Licensed under the Apache License, Version 2.0 (the "License");
  you may not use this file except in compliance with the License.
  You may obtain a copy of the License at

     http://www.apache.org/licenses/LICENSE-2.0

  Unless required by applicable law or agreed to in writing, software
  distributed under the License is distributed on an "AS IS" BASIS,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the License for the specific language governing permissions and
  limitations under the License.
 */
package com.kakao.sdk.sample.common

import android.graphics.Bitmap
import android.graphics.BitmapFactory
import android.os.Bundle
import android.util.Log
import android.view.*
import androidx.fragment.app.Fragment
import androidx.recyclerview.widget.DividerItemDecoration
import androidx.recyclerview.widget.LinearLayoutManager
import androidx.recyclerview.widget.RecyclerView
import com.google.android.material.snackbar.BaseTransientBottomBar.*
import com.google.android.material.snackbar.Snackbar
import com.kakao.sdk.auth.*
import com.kakao.sdk.common.util.KakaoCustomTabsClient
import com.kakao.sdk.link.LinkClient
import com.kakao.sdk.link.WebSharerClient
import com.kakao.sdk.navi.NaviClient
import com.kakao.sdk.navi.model.CoordType
import com.kakao.sdk.navi.model.Location
import com.kakao.sdk.navi.model.NaviOptions
import com.kakao.sdk.story.StoryApiClient
import com.kakao.sdk.talk.TalkApiClient
import com.kakao.sdk.template.*
import com.kakao.sdk.user.UserApiClient
import io.reactivex.Single
import io.reactivex.disposables.CompositeDisposable
import io.reactivex.functions.Action
import io.reactivex.functions.Consumer
import io.reactivex.rxkotlin.addTo
import kotlinx.android.synthetic.main.fragment_open.*
import java.io.File
import java.io.FileOutputStream

class OpenFragment : Fragment() {

    private lateinit var viewAdapter: RecyclerView.Adapter<*>
    private lateinit var viewManager: RecyclerView.LayoutManager
    private lateinit var disposables: CompositeDisposable

    val onSuccess = Consumer<Any> {
        showSnackbar(it)
    }

    val onError = Consumer<Throwable> {
        showSnackbar(it)
    }

    val onCompletableSuccess = Action {
        showSnackbar("API succeeded.")
    }

    private fun showSnackbar(any: Any) {
        val snackbar = Snackbar.make(view!!, any.toString(), LENGTH_LONG)
        val layout = snackbar.view as Snackbar.SnackbarLayout
        layout.minimumHeight = 100
        snackbar.show()
    }

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)
        disposables = CompositeDisposable()

        viewManager = LinearLayoutManager(context!!)
        viewAdapter = ApiAdapter(
            listOf(
                ApiAdapter.Item.Header("Kakao Login"),
                ApiAdapter.Item.ApiItem("isTalkLoginAvailable()") {
                    Single.just(AuthCodeClient.rx.isTalkLoginAvailable(context!!))
                        .subscribe({ showSnackbar(it) }) { showSnackbar(it) }.addTo(disposables)
                },
                ApiAdapter.Item.ApiItem("loginUsingTalk()") {
                    LoginClient.instance.loginUsingTalk(context!!) { token, error ->
                        if (error != null) {
                            showSnackbar(error)
                        } else {
                            showSnackbar(token!!)
                        }
                    }
                },
                ApiAdapter.Item.ApiItem("loginUsingCustomTabs()") {
                    LoginClient.instance.loginUsingCustomTabs(context!!) { token, error ->
                        if (error != null) {
                            showSnackbar(error)
                        } else {
                            showSnackbar(token!!)
                        }
                    }
                },
                ApiAdapter.Item.Header("User API"),
                ApiAdapter.Item.ApiItem("me()") {
                    UserApiClient.instance.me { user, error ->
                        if (error != null) {
                            showSnackbar(error)
                        } else {
                            showSnackbar(user!!)
                        }
                    }
                },
                ApiAdapter.Item.ApiItem("me() - if requires email") {
                    UserApiClient.instance.me { user, error ->
                        if (error != null) {
                            showSnackbar(error)
                        } else {
                            user?.kakaoAccount?.let {
                                if (it.email != null) {
                                    showSnackbar(it.email!!)

                                } else if (it.emailNeedsAgreement == true) {

                                    val scopes = listOf("account_email")

                                    LoginClient.instance.loginWithNewAgreements(context!!, scopes) { _, error ->
                                        if (error != null) {
                                            showSnackbar(error)
                                        } else {

                                            UserApiClient.instance.me { user, error ->
                                                if (error != null) {
                                                    showSnackbar(error)
                                                } else {
                                                    showSnackbar(user?.kakaoAccount?.email!!)
                                                }
                                            }
                                        }
                                    }
                                }
                            }
                        }
                    }
                },
                ApiAdapter.Item.ApiItem("accessTokenInfo()") {
                    UserApiClient.instance.accessTokenInfo { info, error ->
                        if (info != null) {
                            showSnackbar("id:${info.id}, expires_in:${info.expiresIn}, millis:${info.expiresInMillis}")
                        } else if (error != null) {
                            showSnackbar(error)
                        }
                    }
                },
                ApiAdapter.Item.ApiItem("accessTokenInfo() * 3") {
                    for (i in 0..3) {
                        UserApiClient.instance.accessTokenInfo { info, error ->
                            if (info != null) {
                                showSnackbar(info)
                            } else if (error != null) {
                                showSnackbar(error)
                            }
                        }
                    }
                },
                ApiAdapter.Item.ApiItem("updateProfile()") {
                    val properties = mapOf("nickname" to "${System.currentTimeMillis()}")
                    UserApiClient.instance.updateProfile(properties) { error ->
                        if (error != null) {
                            showSnackbar(error)
                        } else {
                            showSnackbar("부가정보 업데이트 완료")
                        }
                    }
                },
                ApiAdapter.Item.ApiItem("shippingAddresses()") {
                    UserApiClient.instance.shippingAddresses { userShippingAddresses, error ->
                        if (userShippingAddresses != null) {
                            showSnackbar(userShippingAddresses)
                        } else if (error != null) {
                            showSnackbar(error)
                        }
                    }
                },
                ApiAdapter.Item.ApiItem("serviceTerms()") {
                    UserApiClient.instance.serviceTerms { userServiceTerms, error ->
                        if (userServiceTerms != null) {
                            showSnackbar(userServiceTerms)
                        } else if (error != null) {
                            showSnackbar(error)
                        }
                    }
                },
                ApiAdapter.Item.ApiItem("logout()") {
                    UserApiClient.instance.logout { error ->
                        if (error != null) {
                            showSnackbar(error)
                        } else {
                            showSnackbar("로그아웃 성공")
                        }
                    }
                },
                ApiAdapter.Item.ApiItem("unlink()") {
                    UserApiClient.instance.unlink { error ->
                        if (error != null) {
                            showSnackbar(error)
                        } else {
                            showSnackbar("연결끊기 성공")
                        }
                    }
                },
                ApiAdapter.Item.Header("KakaoTalk API"),
                ApiAdapter.Item.ApiItem("profile()") {
                    TalkApiClient.instance.profile { profile, error ->
                        if (error != null) {
                            showSnackbar(error)
                        } else {
                            showSnackbar(profile!!)
                        }
                    }
                },
                ApiAdapter.Item.ApiItem("sendCustomMemo()") {
                    val templateId = templateIds["customMessage"] as Long

                    TalkApiClient.instance.sendCustomMemo(templateId) { error ->
                        if (error != null) {
                            showSnackbar(error)
                        } else {
                            showSnackbar("나에게 보내기 성공")
                        }
                    }
                },
                ApiAdapter.Item.ApiItem("sendDefaultMemo()") {
                    val template = defaultFeed

                    TalkApiClient.instance.sendDefaultMemo(template) { error ->
                        if (error != null) {
                            showSnackbar(error)
                        } else {
                            showSnackbar("나에게 보내기 성공")
                        }
                    }
                },
                ApiAdapter.Item.ApiItem("sendScrapMemo()") {
                    val url = "https://developers.kakao.com"

                    TalkApiClient.instance.sendScrapMemo(url) { error ->
                        if (error != null) {
                            showSnackbar(error)
                        } else {
                            showSnackbar("나에게 보내기 성공")
                        }
                    }
                },
                ApiAdapter.Item.ApiItem("friends()") {
                    TalkApiClient.instance.friends { friends, error ->
                        if (error != null) {
                            showSnackbar(error)
                        } else {
                            showSnackbar(friends!!)
                        }
                    }
                },
                ApiAdapter.Item.ApiItem("sendCustomMessage()") {
                    TalkApiClient.instance.friends { friends, error ->
                        if (error != null) {
                            showSnackbar(error)
                        } else if (friends != null) {
                            if (friends.elements.isEmpty()) {
                                showSnackbar("메시지 보낼 친구가 없습니다.")
                            } else {
                                FriendsActivity.startForResult(
                                    context!!,
                                    friends.elements.map { PickerItem(it.uuid, it.profileNickname, it.profileThumbnailImage) }
                                ) { selectedItems ->
                                    if (selectedItems.isEmpty()) return@startForResult

                                    val templateId = templateIds["customMessage"] as Long

                                    TalkApiClient.instance.sendCustomMessage(selectedItems, templateId) { result, error ->
                                        if (error != null) {
                                            showSnackbar(error)
                                        } else {
                                            showSnackbar("메시지 보내기 성공 ${result!!.successfulReceiverUuids}")
                                        }
                                    }
                                }
                            }
                        }
                    }
                },
                ApiAdapter.Item.ApiItem("sendDefaultMessage()") {
                    TalkApiClient.instance.friends { friends, error ->
                        if (error != null) {
                            showSnackbar(error)
                        } else if (friends != null) {
                            if (friends.elements.isEmpty()) {
                                showSnackbar("메시지 보낼 친구가 없습니다.")
                            } else {
                                FriendsActivity.startForResult(
                                    context!!,
                                    friends.elements.map { PickerItem(it.uuid, it.profileNickname, it.profileThumbnailImage) }
                                ) { selectedItems ->
                                    if (selectedItems.isEmpty()) return@startForResult

                                    val template = defaultFeed

                                    TalkApiClient.instance.sendDefaultMessage(selectedItems, template) { result, error ->
                                        if (error != null) {
                                            showSnackbar(error)
                                        } else {
                                            showSnackbar("메시지 보내기 성공 ${result!!.successfulReceiverUuids}")
                                        }
                                    }
                                }
                            }
                        }
                    }
                },
                ApiAdapter.Item.ApiItem("sendScrapMessage()") {
                    TalkApiClient.instance.friends { friends, error ->
                        if (error != null) {
                            showSnackbar(error)
                        } else if (friends != null) {
                            if (friends.elements.isEmpty()) {
                                showSnackbar("메시지 보낼 친구가 없습니다.")
                            } else {
                                FriendsActivity.startForResult(
                                    context!!,
                                    friends.elements.map { PickerItem(it.uuid, it.profileNickname, it.profileThumbnailImage) }
                                ) { selectedItems ->
                                    if (selectedItems.isEmpty()) return@startForResult

                                    val url = "https://developers.kakao.com"

                                    TalkApiClient.instance.sendScrapMessage(selectedItems, url) { result, error ->
                                        if (error != null) {
                                            showSnackbar(error)
                                        } else {
                                            showSnackbar("메시지 보내기 성공 ${result!!.successfulReceiverUuids}")
                                        }
                                    }
                                }
                            }
                        }
                    }
                },
                ApiAdapter.Item.ApiItem("channels()") {
                    TalkApiClient.instance.channels { relations, error ->
                        if (error != null) {
                            showSnackbar(error)
                        } else {
                            showSnackbar(relations!!)
                        }
                    }
                },
                ApiAdapter.Item.ApiItem("addChannelUrl()") {
                    val url = TalkApiClient.instance.addChannelUrl("_ZeUTxl")

                    KakaoCustomTabsClient.openWithDefault(context!!, url)
                },
                ApiAdapter.Item.ApiItem("channelChatUrl()") {
                    val url = TalkApiClient.instance.channelChatUrl("_ZeUTxl")

                    KakaoCustomTabsClient.openWithDefault(context!!, url)
                },
                ApiAdapter.Item.Header("KakaoStory API"),
                ApiAdapter.Item.ApiItem("isStoryUser()") {
                    StoryApiClient.instance.isStoryUser { isStoryUser, error ->
                        if (error != null) {
                            showSnackbar(error)
                        } else {
                            showSnackbar("isStoryUser: $isStoryUser")
                        }
                    }
                },
                ApiAdapter.Item.ApiItem("profile()") {
                    StoryApiClient.instance.profile { profile, error ->
                        if (error != null) {
                            showSnackbar(error)
                        } else {
                            showSnackbar(profile!!)
                        }
                    }
                },
                ApiAdapter.Item.ApiItem("stories()") {
                    StoryApiClient.instance.stories { stories, error ->
                        if (error != null) {
                            showSnackbar(error)
                        } else {
                            showSnackbar(stories!!)
                        }
                    }
                },
                ApiAdapter.Item.ApiItem("story(id:) - first of stories") {
                    StoryApiClient.instance.stories { stories, error ->
                        if (error != null) {
                            showSnackbar(error)
                        } else if (stories != null) {
                            if (stories.isEmpty()) {
                                showSnackbar("내 스토리가 하나도 없어요 ㅠㅠ")
                            } else {
                                StoryApiClient.instance.story(stories.first().id) { story, error ->
                                    if (error != null) {
                                        showSnackbar(error)
                                    } else if (story != null) {
                                        showSnackbar(story)
                                    }
                                }
                            }
                        }
                    }
                },
                ApiAdapter.Item.ApiItem("delete(id:) - first of stories") {
                    StoryApiClient.instance.stories { stories, error ->
                        if (error != null) {
                            showSnackbar(error)
                        } else if (stories != null) {
                            if (stories.isEmpty()) {
                                showSnackbar("내 스토리가 하나도 없어요 ㅠㅠ")
                            } else {
                                val id = stories.first().id

                                StoryApiClient.instance.delete(id) { error ->
                                    if (error != null) {
                                        showSnackbar(error)
                                    } else {
                                        showSnackbar("스토리 삭제 완료 [$id]")
                                    }
                                }
                            }
                        }
                    }
                },
                ApiAdapter.Item.ApiItem("linkInfo()") {
                    StoryApiClient.instance.linkInfo("https://www.kakaocorp.com") { linkInfo, error ->
                        if (error != null) {
                            showSnackbar(error)
                        } else {
                            showSnackbar(linkInfo!!)
                        }
                    }
                },
                ApiAdapter.Item.ApiItem("postNote()") {
                    StoryApiClient.instance.postNote("Posting note from Kakao SDK Sample.") { storyPostResult, error ->
                        if (error != null) {
                            showSnackbar(error)
                        } else {
                            showSnackbar(storyPostResult?.id!!)
                        }
                    }
                },
                ApiAdapter.Item.ApiItem("postLink()") {
                    StoryApiClient.instance.linkInfo("https://www.kakaocorp.com") { linkInfo, error ->
                        if (error != null) {
                            showSnackbar(error)
                        } else {
                            StoryApiClient.instance.postLink(linkInfo!!, "Posting link from Kakao SDK Sample.") { storyPostResult, error ->
                                if (error != null) {
                                    showSnackbar(error)
                                } else {
                                    showSnackbar(storyPostResult?.id!!)
                                }
                            }
                        }
                    }
                },
                ApiAdapter.Item.ApiItem("postPhoto()") {
                    val bitmap = BitmapFactory.decodeResource(resources, R.drawable.sample1)
                    val file = File(context!!.cacheDir, "sample1.png")
                    val stream = FileOutputStream(file)
                    bitmap.compress(Bitmap.CompressFormat.PNG, 100, stream)
                    stream.close()

                    StoryApiClient.instance.upload(listOf(file)) { uploadedPaths, error ->
                        if (error != null) {
                            showSnackbar(error)
                        } else {
                            StoryApiClient.instance.postPhoto(uploadedPaths!!, "Posting photo from Kakao SDK Sample.") { storyPostResult, error ->
                                if (error != null) {
                                    showSnackbar(error)
                                } else {
                                    showSnackbar(storyPostResult?.id!!)
                                }
                            }
                        }
                    }
                },
                ApiAdapter.Item.Header("KakaoLink API"),
                ApiAdapter.Item.ApiItem("isKakaoLinkAvailable()") {
                    val available = LinkClient.instance.isKakaoLinkAvailable(context!!)
                    showSnackbar("isKakaoLinkAvailable: $available")
                },
                ApiAdapter.Item.ApiItem("customTemplate()") {
                    val templateId = templateIds["customMemo"] as Long

                    LinkClient.instance.customTemplate(context!!, templateId) { linkResult, error ->
                        if (error != null) {
                            showSnackbar(error)
                        } else {
                            startActivity(linkResult!!.intent)

                            Log.w("LinkResult", "Warning Msg: ${linkResult!!.warningMsg}")
                            Log.w("LinkResult", "Argument Msg: ${linkResult!!.argumentMsg}")
                        }
                    }
                },
                ApiAdapter.Item.ApiItem("scrapTemplate()") {
                    val url = "https://developers.kakao.com"

                    LinkClient.instance.scrapTemplate(context!!, url) { linkResult, error ->
                        if (error != null) {
                            showSnackbar(error)
                        } else {
                            startActivity(linkResult!!.intent)

                            Log.w("LinkResult", "Warning Msg: ${linkResult!!.warningMsg}")
                            Log.w("LinkResult", "Argument Msg: ${linkResult!!.argumentMsg}")
                        }
                    }
                },
                ApiAdapter.Item.ApiItem("defaultTemplate()") {
                    LinkClient.instance.defaultTemplate(context!!, defaultFeed) { linkResult, error ->
                        if (error != null) {
                            showSnackbar(error)
                        } else {
                            startActivity(linkResult!!.intent)

                            Log.w("LinkResult", "Warning Msg: ${linkResult!!.warningMsg}")
                            Log.w("LinkResult", "Argument Msg: ${linkResult!!.argumentMsg}")
                        }
                    }
                },
                ApiAdapter.Item.ApiItem("defaultTemplate() - list") {
                    LinkClient.instance.defaultTemplate(context!!, defaultList) { linkResult, error ->
                        if (error != null) {
                            showSnackbar(error)
                        } else {
                            startActivity(linkResult!!.intent)

                            Log.w("LinkResult", "Warning Msg: ${linkResult!!.warningMsg}")
                            Log.w("LinkResult", "Argument Msg: ${linkResult!!.argumentMsg}")
                        }
                    }
                },
                ApiAdapter.Item.ApiItem("defaultTemplate() - location") {
                    LinkClient.instance.defaultTemplate(context!!, defaultLocation) { linkResult, error ->
                        if (error != null) {
                            showSnackbar(error)
                        } else {
                            startActivity(linkResult!!.intent)

                            Log.w("LinkResult", "Warning Msg: ${linkResult!!.warningMsg}")
                            Log.w("LinkResult", "Argument Msg: ${linkResult!!.argumentMsg}")
                        }
                    }
                },
                ApiAdapter.Item.ApiItem("defaultTemplate() - commerce") {
                    LinkClient.instance.defaultTemplate(context!!, defaultCommerce) { linkResult, error ->
                        if (error != null) {
                            showSnackbar(error)
                        } else {
                            startActivity(linkResult!!.intent)

                            Log.w("LinkResult", "Warning Msg: ${linkResult!!.warningMsg}")
                            Log.w("LinkResult", "Argument Msg: ${linkResult!!.argumentMsg}")
                        }
                    }
                },
                ApiAdapter.Item.ApiItem("defaultTemplate() - text") {
                    LinkClient.instance.defaultTemplate(context!!, defaultText) { linkResult, error ->
                        if (error != null) {
                            showSnackbar(error)
                        } else {
                            startActivity(linkResult!!.intent)

                            Log.w("LinkResult", "Warning Msg: ${linkResult!!.warningMsg}")
                            Log.w("LinkResult", "Argument Msg: ${linkResult!!.argumentMsg}")
                        }
                    }
                },
                ApiAdapter.Item.ApiItem("customTemplateUri() - web sharer") {
                    val shareUrl = WebSharerClient.instance.customTemplateUri(templateIds["customMemo"] as Long)

                    KakaoCustomTabsClient.openWithDefault(context!!, shareUrl)
                },
                ApiAdapter.Item.ApiItem("scrapTemplateUri() - web sharer") {
                    val shareUrl = WebSharerClient.instance.scrapTemplateUri("https://developers.kakao.com")

                    KakaoCustomTabsClient.openWithDefault(context!!, shareUrl)
                },
                ApiAdapter.Item.ApiItem("defaultTemplateUri() - web sharer") {
                    val shareUrl = WebSharerClient.instance.defaultTemplateUri(defaultFeed)

                    KakaoCustomTabsClient.openWithDefault(context!!, shareUrl)
                },
                ApiAdapter.Item.ApiItem("defaultTemplateUri() - location with web sharer") {
                    val shareUrl = WebSharerClient.instance.defaultTemplateUri(defaultLocation)

                    KakaoCustomTabsClient.openWithDefault(context!!, shareUrl)
                },
                ApiAdapter.Item.ApiItem("uploadImage()") {
                    val bitmap = BitmapFactory.decodeResource(resources, R.drawable.sample1)
                    val file = File(context!!.cacheDir, "sample1.png")
                    val stream = FileOutputStream(file)
                    bitmap.compress(Bitmap.CompressFormat.PNG, 100, stream)
                    stream.close()
                    LinkClient.instance.uploadImage(file) { imageUploadResult, error ->
                        if (error != null) {
                            showSnackbar(error)
                        } else {
                            showSnackbar(imageUploadResult!!)
                        }
                    }
                },
                ApiAdapter.Item.Header("KakaoNavi API"),
                ApiAdapter.Item.ApiItem("isKakaoNaviInstalled()") {
                    val naviInstalled = NaviClient.instance.isKakaoNaviInstalled(context!!)

                    showSnackbar("isKakaoNaviInstalled: $naviInstalled")
                },
                ApiAdapter.Item.ApiItem("shareDestinationIntent()") {
                    val intent =
                        NaviClient.instance.shareDestinationIntent(
                            Location("카카오 판교 오피스", 127.10821222694533, 37.40205604363057),
                            NaviOptions(coordType = CoordType.WGS84)
                        )
                    startActivity(intent)
                },
                ApiAdapter.Item.ApiItem("navigateIntent()") {
                    val intent =
                        NaviClient.instance.navigateIntent(
                            Location("카카오 판교 오피스", 127.10821222694533, 37.40205604363057),
                            NaviOptions(coordType = CoordType.WGS84)
                        )
                    startActivity(intent)
                },
                ApiAdapter.Item.ApiItem("shareDestinationUri()") {
                    val uri =
                        NaviClient.instance.navigateUrl(
                            Location("카카오 판교 오피스", 127.10821222694533, 37.40205604363057),
                            NaviOptions(coordType = CoordType.WGS84)
                        )
                    KakaoCustomTabsClient.openWithDefault(context!!, uri)
                }
            )
        )
        recyclerView.apply {
            setHasFixedSize(true)
            addItemDecoration(
                DividerItemDecoration(context, DividerItemDecoration.VERTICAL)
            )
            layoutManager = viewManager
            adapter = viewAdapter
        }
    }

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        arguments?.let {
            templateIds = it
        }
    }

    override fun onCreateView(
        inflater: LayoutInflater, container: ViewGroup?,
        savedInstanceState: Bundle?
    ): View? {
        // Inflate the layout for this fragment
        val view = inflater.inflate(R.layout.fragment_open, container, false)
//        setHasOptionsMenu(true)
        return view
    }

//    override fun onCreateOptionsMenu(menu: Menu, inflater: MenuInflater) {
//        inflater.inflate(R.menu.menu_main, menu)
//        super.onCreateOptionsMenu(menu, inflater)
//
//    }

    override fun onDestroy() {
        disposables.dispose()
        super.onDestroy()
    }

    private lateinit var templateIds: Bundle

    companion object {
        fun newInstance(templateIds: Bundle): OpenFragment =
            OpenFragment().apply {
                arguments = templateIds
            }

        val defaultFeed = FeedTemplate(
            content = Content(
                "딸기 치즈 케익",
                "http://mud-kage.kakao.co.kr/dn/Q2iNx/btqgeRgV54P/VLdBs9cvyn8BJXB3o7N8UK/kakaolink40_original.png",
                Link(
                    "https://developers.kakao.com",
                    "https://developers.kakao.com"
                ),
                description = "#케익 #딸기 #삼평동 #카페 #분위기 #소개팅"
            ),
            social = Social(),
            buttons = listOf(
                Button(
                    "웹으로 보기",
                    Link(
                        "https://developers.kakao.com",
                        "https://developers.kakao.com"
                    )
                ),
                Button(
                    "앱으로 보기",
                    Link(
                        "https://developers.kakao.com",
                        "https://developers.kakao.com",
                        mapOf("key1" to "value1", "key2" to "value2"),
                        mapOf("key1" to "value1", "key2" to "value2")
                    )
                )
            )
        )

        val defaultList = ListTemplate(
            headerTitle = "WEEKLY MAGAZINE",
            headerLink = Link(
                webUrl = "https://developers.kakao.com",
                mobileWebUrl = "https://developers.kakao.com"
            ),
            contents = listOf(
                Content(
                    title = "취미의 특징, 탁구",
                    description = "스포츠",
                    imageUrl = "http://mud-kage.kakao.co.kr/dn/bDPMIb/btqgeoTRQvd/49BuF1gNo6UXkdbKecx600/kakaolink40_original.png",
                    link = Link(
                        webUrl = "https://developers.kakao.com",
                        mobileWebUrl = "https://developers.kakao.com"
                    )
                ),
                Content(
                    title = "크림으로 이해하는 커피이야기",
                    description = "음식",
                    imageUrl = "http://mud-kage.kakao.co.kr/dn/QPeNt/btqgeSfSsCR/0QJIRuWTtkg4cYc57n8H80/kakaolink40_original.png",
                    link = Link(
                        webUrl = "https://developers.kakao.com",
                        mobileWebUrl = "https://developers.kakao.com"
                    )
                ),
                Content(
                    title = "감성이 가득한 분위기",
                    description = "사진",
                    imageUrl = "http://mud-kage.kakao.co.kr/dn/c7MBX4/btqgeRgWhBy/ZMLnndJFAqyUAnqu4sQHS0/kakaolink40_original.png",
                    link = Link(
                        webUrl = "https://developers.kakao.com",
                        mobileWebUrl = "https://developers.kakao.com"
                    )
                )
            ),
            buttons = listOf(
                Button(
                    "웹으로 보기",
                    Link(
                        webUrl = "https://developers.kakao.com",
                        mobileWebUrl = "https://developers.kakao.com"
                    )
                ),
                Button(
                    "앱으로 보기",
                    Link(
                        androidExecParams = mapOf("key1" to "value1", "key2" to "value2"),
                        iosExecParams = mapOf("key1" to "value1", "key2" to "value2")
                    )
                )
            )
        )

        val defaultLocation = LocationTemplate(
            content = Content(
                title = "카카오톡 링크",
                description = "디폴트 템플릿 Location",
                imageUrl = "http://alpha-api1-kage.kakao.com/dn/cerDB5/ZSb2iRugKx/M4nuZxX823tnK1Mk5yVcv0/kakaolink40_original.png",
                link = Link(
                    webUrl = "https://developers.com",
                    mobileWebUrl = "https://developers.kakao.com"
                )
            ),
            social = Social(likeCount = 100, commentCount = 200),
            buttonTitle = "바로 확인",
            address = "경기 성남시 분당구 판교역로 235 에이치스퀘어 N동 7층",
            addressTitle = "카카오"
        )

        val defaultCommerce = CommerceTemplate(
            content = Content(
                title = "카카오톡 링크",
                description = "디폴트 템플릿 Commerce",
                imageUrl = "http://alpha-api1-kage.kakao.com/dn/cerDB5/ZSb2iRugKx/M4nuZxX823tnK1Mk5yVcv0/kakaolink40_original.png",
                link = Link(
                    webUrl = "https://developers.kakao.com",
                    mobileWebUrl = "https://developers.kakao.com"
                )
            ),
            commerce = Commerce(
                regularPrice = 10000,
                productName = "상품명"
            ),
            buttonTitle = "바로 확인"
        )

        val defaultText = TextTemplate(
            text = """
                카카오링크는 카카오 플랫폼 서비스의 대표 기능으로써 사용자의 모바일 기기에 설치된 카카오 플랫폼과 연동하여 다양한 기능을 실행할 수 있습니다.
                현재 이용할 수 있는 카카오링크는 다음과 같습니다.
                카카오톡링크
                카카오톡을 실행하여 사용자가 선택한 채팅방으로 메시지를 전송합니다.
                카카오스토리링크
                카카오스토리 글쓰기 화면으로 연결합니다.
            """.trimIndent(),
            link = Link(
                webUrl = "http://developers.kakao.com",
                mobileWebUrl = "http://dev.kakao.om"
            )
        )

    }
}
